.. _examples:

Examples
========

All examples are available as
`Jupyter notebooks <https://jupyter.org/>`_
from the *hklpy* source
code website: https://github.com/bluesky/hklpy/tree/main/examples

.. _examples.diffractometer:

Diffractometer Geometries
-------------------------

See also the documentation for the :ref:`geometries` module.

.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/geo_*

How-to Guides
-------------

.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/how_*

Variations
----------

.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/var_*

Tests and Comparisons
---------------------

.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/tst_*
